From 053daf00b5037e1644a56d26f964b9ef7d6eb27f Mon Sep 17 00:00:00 2001
From: Sergey Radionov <RSATom@gmail.com>
Date: Thu, 17 Nov 2011 21:15:23 +0700
Subject: [PATCH 2/4] npapi: Changed files to be compilable by VC.

---
 npapi/control/npolibvlc.cpp |    8 +++++++-
 npapi/control/nporuntime.h  |    7 +++++++
 npapi/control/position.h    |    4 ++++
 npapi/support/npwin.cpp     |   11 +++++++++--
 npapi/vlcplugin.cpp         |   12 ++++++++++++
 npapi/vlcplugin.h           |    7 +++++++
 npapi/vlcshell.cpp          |    5 +++++
 7 files changed, 51 insertions(+), 3 deletions(-)

diff --git a/npapi/control/npolibvlc.cpp b/npapi/control/npolibvlc.cpp
index 515c459..96ab261 100644
--- a/npapi/control/npolibvlc.cpp
+++ b/npapi/control/npolibvlc.cpp
@@ -1871,12 +1871,18 @@ LibvlcLogoNPObject::invoke(int index, const NPVariant *args,
     return INVOKERESULT_NO_ERROR;
 }
 
-
+#ifdef _MSC_VER
+const NPUTF8 * const LibvlcDeinterlaceNPObject::propertyNames[] = {
+    ""
+};
+const int LibvlcDeinterlaceNPObject::propertyCount=0;
+#else
 const NPUTF8 * const LibvlcDeinterlaceNPObject::propertyNames[] = {
 };
 enum LibvlcDeinterlaceNPObjectPropertyIds {
 };
 COUNTNAMES(LibvlcDeinterlaceNPObject,propertyCount,propertyNames);
+#endif //_MSC_VER
 
 RuntimeNPObject::InvokeResult
 LibvlcDeinterlaceNPObject::getProperty(int index, NPVariant &result)
diff --git a/npapi/control/nporuntime.h b/npapi/control/nporuntime.h
index fe9bfc6..c58864f 100644
--- a/npapi/control/nporuntime.h
+++ b/npapi/control/nporuntime.h
@@ -29,7 +29,14 @@
 ** support framework for runtime script objects
 */
 
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
 #include <npapi.h>
+#endif //_MSC_VER
+
 #include <npruntime.h>
 
 static void RuntimeNPClassDeallocate(NPObject *npobj);
diff --git a/npapi/control/position.h b/npapi/control/position.h
index ec1c7f8..0a0564f 100644
--- a/npapi/control/position.h
+++ b/npapi/control/position.h
@@ -47,7 +47,11 @@ static inline const char *position_bynumber( size_t i )
 static inline bool position_byname( const char *n, size_t &i )
 {
     for( const posidx_s *h=posidx; h<posidx+num_posidx; ++h )
+#ifdef _MSC_VER
+        if( !_stricmp( n, h->n ) )
+#else
         if( !strcasecmp( n, h->n ) )
+#endif
             { i=h->i; return true; }
     return false;
 }
diff --git a/npapi/support/npwin.cpp b/npapi/support/npwin.cpp
index 7fe6d31..f9ef0fd 100644
--- a/npapi/support/npwin.cpp
+++ b/npapi/support/npwin.cpp
@@ -35,8 +35,15 @@
 #include "../vlcplugin.h"
 
 #ifndef _NPAPI_H_
-#   include "npapi.h"
-#endif
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
+#include <npapi.h>
+#endif //_MSC_VER
+#endif //_NPAPI_H_
+
 #if (((NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR) < 20)
 #include "npupp.h"
 #else
diff --git a/npapi/vlcplugin.cpp b/npapi/vlcplugin.cpp
index 41c5e83..e6b3ac1 100644
--- a/npapi/vlcplugin.cpp
+++ b/npapi/vlcplugin.cpp
@@ -423,11 +423,19 @@ VlcPlugin::VlcPlugin( NPP instance, uint16_t mode ) :
 #endif
 }
 
+#ifdef _MSC_VER
+static bool boolValue(const char *value) {
+    return ( !strcmp(value, "1") ||
+             !_stricmp(value, "true") ||
+             !_stricmp(value, "yes") );
+}
+#else
 static bool boolValue(const char *value) {
     return ( !strcmp(value, "1") ||
              !strcasecmp(value, "true") ||
              !strcasecmp(value, "yes") );
 }
+#endif //_MSC_VER
 
 void VlcPlugin::eventAsync(void *param)
 {
@@ -443,7 +451,11 @@ void VlcPlugin::event_callback(const libvlc_event_t* event,
     plugin->events.callback(event, npparams, npcount);
     NPN_PluginThreadAsyncCall(plugin->getBrowser(), eventAsync, plugin);
 #else
+#ifdef _MSC_VER
+#pragma message("NPN_PluginThreadAsyncCall not implemented yet.")
+#else
 #warning NPN_PluginThreadAsyncCall not implemented yet.
+#endif //_MSC_VER
     printf("No NPN_PluginThreadAsyncCall(), doing nothing.\n");
 #endif
 }
diff --git a/npapi/vlcplugin.h b/npapi/vlcplugin.h
index 8b4a566..ed90fb7 100644
--- a/npapi/vlcplugin.h
+++ b/npapi/vlcplugin.h
@@ -80,7 +80,14 @@
 
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
 #include <npapi.h>
+#endif //_MSC_VER
+
 #include <vector>
 #include <assert.h>
 
diff --git a/npapi/vlcshell.cpp b/npapi/vlcshell.cpp
index f6d55a3..f2f07b7 100644
--- a/npapi/vlcshell.cpp
+++ b/npapi/vlcshell.cpp
@@ -87,8 +87,13 @@ NPError NPP_GetValue( NPP instance, NPPVariable variable, void *value )
             return NPERR_NO_ERROR;
 
         case NPPVpluginDescriptionString:
+#ifdef _MSC_VER
+            _snprintf( psz_desc, sizeof(psz_desc), PLUGIN_DESCRIPTION,
+                      libvlc_get_version() );
+#else
             snprintf( psz_desc, sizeof(psz_desc), PLUGIN_DESCRIPTION,
                       libvlc_get_version() );
+#endif //_MSC_VER
             *((char **)value) = psz_desc;
             return NPERR_NO_ERROR;
 
-- 
1.7.7.1.msysgit.0

